encoding="utf-8
# whereisthemouse

A simple Python package to **send message to line chat window** on the desktop. 

## Usage

```python
import autoline
autoline.send('chat group title','message to send')
autoline.hideWindow('chat group title')
```

## Features

- Display current mouse position and pixel color value.
- Press `Alt` to copy the information to the clipboard.

## License

MIT License
